/**
* An element holder for Yagi-style antennas.
* To connect antenna elements with 6mm diameter over a 10mm boom.
* A single M3 screw and two nuts for each element is required only.
*/

$fn = 100;
boomX = 10.05;
boomY = 10.05;
thick = 1.2;
boomLength = 15;
elementD = 6;
length = 20;

boom_holder = [
[0,0], 
[1,boomY + 2*thick], 
[1 + 2*thick,boomY + 2*thick], 
[1 + 2*thick,boomY + thick + 0.2], 
[1 + thick,boomY + thick], 
[1 + thick,thick], 
[1 + boomX+ thick,thick], 
[1 + boomX + thick,boomY + thick],
[1 + boomX,boomY + thick + 0.2],
[1 + boomX,boomY + 2*thick],
[1 + boomX + 2*thick,boomY + 2*thick],
[1 + boomX + 2*thick + 1,0]
];

union() {
  //boom section
  translate([0,-0.5,0])
    difference() {    
      linear_extrude(boomLength)polygon(boom_holder);
      translate([0,boomY/2 + thick,boomLength/2])rotate([0,90,0])cylinder(h=boomX * 2, r1=1.5, r2=1.5);
      translate([7.5,10,12])rotate([90,0,0])cylinder(h=40,r1=1.6,r2=1.6);
    }
  // middle section
  translate([0.5,-10 + 1 ,0])
    difference() {
        cube([boomX + 2*thick + 1,9,elementD + 3]);
        translate([2.2,0,1])cube([boomX-1,9,elementD + 3]);
    }
  //element section  
  translate([-2.5, -elementD/2 - 9, elementD/2 + 2]) rotate([0,90,0]) elementHolder();
}

module elementHolder() {
  element_holder = [
[0,1],
[0,length-1],
[elementD/2 + 2,length],
[elementD/2 + 2,0]];

  difference() {
    union() {
        rotate_extrude(convexity = 100) polygon(element_holder);
        translate([-10,-2.3,0])cube([7,5, length]);
    }
    cylinder(h=length, r1=elementD/2, r2=elementD/2); // 6mm hole for the element
    translate([-10.5,0,0]) cube([8,0.5, length]);

    //M3 screw and nut
    translate([-7,2.6,length - 10]) {
        nutM3();
        rotate([90,0,0]) translate([0,0,-1])cylinder(h=6,r1=1.6,r2=1.6);
    }
  }
}

module nutM3() {
  s = 5.5;
  m = 1.2; 
  rotate([90,30,0]) {
      difference() {
          union() {
            rotate([0,0,30]) cube([s,s/1.7, m], center = true);
            rotate([0,0,90]) cube([s,s/1.7, m], center = true);
            rotate([0,0,150]) cube([s,s/1.7, m], center = true);
          }
      }
  }
}